@@ -69,7 +69,7 @@ class Command(BaseCommand):
         
         for file_path in file_paths:
             if not os.path.isfile(file_path):
-                print "File %s not found." % filename
+                print "File %s not found." % file_path
                 continue
             f = file(file_path, 'r')
             data = f.readlines()
