@@ -34,8 +34,11 @@ class Category(MPTTModel):
         blank=True,
         default="",
         max_length=100,
-        help_text="An alternative title to use on pages with this category."
-    )
+        help_text="An alternative title to use on pages with this category.")
+    alternate_url = models.URLField(
+        blank=True, 
+        verify_exists=False, 
+        help_text="An alternative URL to use instead of the one derived from the category hierarchy.")
     description = models.TextField(blank=True, null=True)
     meta_keywords = models.CharField(
         blank=True,
@@ -53,6 +56,8 @@ class Category(MPTTModel):
     
     def get_absolute_url(self):
         """Return a path"""
+        if self.alternate_url:
+            return self.alternate_url
         prefix = reverse('categories_tree_list')
         ancestors = list(self.get_ancestors()) + [self,]
         return prefix + '/'.join([force_unicode(i.slug) for i in ancestors]) + '/'
